@@ -77,7 +77,7 @@ pew_download <- function(area = "politics",
   remDr$open(silent = TRUE)
 
   # Get list of current download directory contents
-  if (!dir.exists(download_dir)) dir.create(download_dir)
+  if (!dir.exists(download_dir)) dir.create(download_dir, recursive = TRUE)
   dd_old <- list.files(download_dir)
   
   # Loop through files
